pub struct GeoHash { /* private fields */ }Expand description
GeoHash value encoded as base32 string
Implementations
Sourceimpl GeoHash
impl GeoHash
Sourcepub const fn encode(coord: Coordinate, len: usize) -> Option<Self>
pub const fn encode(coord: Coordinate, len: usize) -> Option<Self>
Creates len long geohash for specified coordinates coord.
Returns None if len is not within 1..=12 range
Prefer to use Codec to ensure len is valid at compile time when possible
Sourcepub const fn from_str(text: &str) -> Self
pub const fn from_str(text: &str) -> Self
Creates geohash from string, validating its length within 1..=12 with panic in case of failure
Sourcepub const fn try_from_str(text: &str) -> Option<Self>
pub const fn try_from_str(text: &str) -> Option<Self>
Creates geohash from string, validating its length within 1..=12
Sourcepub const fn decode_bbox(&self) -> Result<Bbox, DecodeError>
pub const fn decode_bbox(&self) -> Result<Bbox, DecodeError>
Decodes geohash into its cell’s coordinates